pub struct Registry;Expand description
The public Registry type — a thin newtype that provides the seeding
interface against a live CompileTimeDb. Created from a lock guard by
validate_query_as.
Implementations
Sourceimpl Registry
impl Registry
Sourcepub fn seed_if_known(table_name: &str, db: &mut CompileTimeDb) -> Result<bool>
pub fn seed_if_known(table_name: &str, db: &mut CompileTimeDb) -> Result<bool>
Seed a registered table into db if it hasn’t been created yet.
Returns true if the table was seeded, false if unknown.
Errors
Returns a Hyper error if the CREATE TABLE command fails.